//
//  TSTGPTextView.swift
//  AIRingtone
//
//  Created by 100Years on 2025/3/4.
//


let kRandomTextArray:[String] = [
    "Ultra-detailed northern lights over a glacial lake, mirrored reflections with vibrant turquoise and magenta hues, surreal celestial atmosphere, digital painting style with soft glow effects.",
    "Neon-lit cyberpunk night market in a rainy Asian metropolis, holographic food stalls and floating drones, teal-orange color grading, retro-futuristic architecture with glowing Kanji signs",
    "Macro photography of rainbow candy landscape with gummy bear mountains, chocolate river and lollipop trees, hyper-realistic textures under golden hour lighting",
    "Traditional Chinese ink painting style phoenix soaring through misty mountain peaks, dynamic black brushstrokes with crimson accents on rice paper texture",
    "Bioluminescent underwater metropolis with glass dome structures, schools of glowing fish weaving through coral skyscrapers, deep-sea blue palette with neon coral highlights",
    "1950s retro sci-fi movie poster style wallpaper featuring a rocket orbiting Saturn, vintage orange-teal color scheme with halftone textures and hand-drawn typography",
    "Minimalist wallpaper with overlapping translucent 3D geometric shapes in gradient pastel colors, clean negative space, soft shadows and metallic accents, 4K abstract design.",
    "Steampunk floating library with brass gears and clockwork mechanisms, leather-bound books flying through amber-lit fog, Victorian-era architecture blended with retro-futurism",
    "Zen rock garden transformed into cosmic landscape, black sand waves surrounding cratered moon-like stones, starry galaxy reflected in miniature, monochromatic with silver foil accents",
    "Futuristic AI core visualization with flowing golden data streams through transparent quantum circuits, dark background with floating holographic equations, cybernetic glow effect"
]


class TSPromptTextView : TSBaseView{
    

    var textChangedBlock:((String)->Void)?
    
    lazy var titleView: TSTGPTitleView = {
        let titleView = TSTGPTitleView()
        titleView.titleLab.text = "Enter A Prompt".localized
        return titleView
    }()
  
    lazy var randomTextPicker: TSRandomTextPicker = {
        let textPicker = TSRandomTextPicker(texts: kRandomTextArray)
        return textPicker
    }()
    
    lazy var textBgView: UIView = {
        let textBgView = UIView()

        let bgImageView = UIImageView.createImageView(imageName: "textView_bg",contentMode: .scaleToFill)
        let lbImageView = UIImageView.createImageView(imageName: "textView_lb",contentMode: .scaleToFill)
        
        textBgView.addSubview(bgImageView)
        textBgView.addSubview(lbImageView)
        
        bgImageView.snp.makeConstraints { make in
            make.top.equalTo(0)
            make.centerX.equalToSuperview()
            make.width.equalTo(343*kDesignScale)
            make.height.equalTo(160*kDesignScale)
        }
        
        lbImageView.snp.makeConstraints { make in
            make.bottom.equalTo(0)
            make.leading.equalTo(0)
            make.width.equalTo(206*kDesignScale)
            make.height.equalTo(32*kDesignScale)
        }
        
        return textBgView
    }()
    
    lazy var customTextView: TSPlaceholderTextView = {
        let customTextView = TSPlaceholderTextView(
            placeholder: "Type your idea here.",
            text: "",
            font: .font(size: 16),
            textColor: .white,
            backgroundColor: .clear
        )
        customTextView.delegate = self
        return customTextView
    }()
    
 
    lazy var inspirationBtn: UIButton = {
        let inspirationBtn = UIButton.createButton(
            title: "Hint Inspiration".localized,
            image: UIImage(named: "textView_hint"),
            font: .font(size: 14),
            titleColor: .themeColor
        )
        { [weak self]  in
            guard let self = self else { return }
            customTextView.text = randomTextPicker.getRandomText()
            textViewDidChange(customTextView)
        }
        inspirationBtn.contentEdgeInsets = UIEdgeInsets(top: 4, left: 24, bottom: 4, right: 50)
        inspirationBtn.imageEdgeInsets = UIEdgeInsets(top: 0, left: -8, bottom: 0, right: 0)
        return inspirationBtn
    }()
    
    
    lazy var clearBtn: TSUIExpandedTouchButton = {
        let clearBtn = TSUIExpandedTouchButton()
        clearBtn.setUpButton(image: UIImage(named: "clear_text"))
//        let clearBtn = UIButton.createButton(
//            image: UIImage(named: "clear_text")
//        )
        { [weak self]  in
            guard let self = self else { return }
            customTextView.text = ""
            textViewDidChange(customTextView)
        }
        return clearBtn
    }()
    
    let maxNum:Int = 1000
    var currenMun:Int = 0 {
        didSet{
            currenMunLab.text = "\(currenMun)"
        }
    }
    lazy var currenMunLab: UILabel = {
        let numLab = UILabel.createLabel(text: "\(currenMun)",font: .font(name: .PingFangSC,size: 12),textColor: .white)
        return numLab
    }()
    
    lazy var numView: UIView = {
        let numView = UIView()
        
        numView.addSubview(currenMunLab)
        
        let numLab = UILabel.createLabel(text: "/\(maxNum))",font: .font(name: .PingFangSC,size: 12),textColor: .white.withAlphaComponent(0.4))
        numView.addSubview(numLab)
        
        let lineView = UIView()
        lineView.cornerRadius = 0.5
        lineView.backgroundColor = .white
        numView.addSubview(lineView)
        
        currenMunLab.snp.makeConstraints { make in
            make.centerY.equalToSuperview()
            make.leading.equalTo(0)
        }
        
        numLab.snp.makeConstraints { make in
            make.centerY.equalToSuperview()
            make.leading.equalTo(currenMunLab.snp.trailing)
        }
        
        lineView.snp.makeConstraints { make in
            make.top.trailing.bottom.equalToSuperview()
            make.leading.equalTo(numLab.snp.trailing).offset(8)
            make.width.equalTo(1)
            make.height.equalTo(12)
        }
        
        return numView
    }()
    
    override func creatUI() {
        let titleViewH = titleView.viewH
        
        addSubview(titleView)
        titleView.snp.makeConstraints { make in
            make.top.equalTo(0)
            make.leading.trailing.equalTo(0)
            make.height.equalTo(titleViewH)
        }
        
        contentView.snp.updateConstraints { make in
            make.top.equalTo(titleViewH)
        }
    
        contentView.addSubview(textBgView)
        textBgView.snp.makeConstraints { make in
            make.top.equalTo(0)
            make.leading.equalTo(16)
            make.trailing.equalTo(-16)
            make.height.equalTo(160.0*kDesignScale)
            make.bottom.equalTo(0)
        }
   
        textBgView.addSubview(customTextView)
        customTextView.snp.makeConstraints { make in
            make.top.equalTo(16)
            make.leading.equalTo(16)
            make.trailing.equalTo(-16)
            make.bottom.equalTo(-48)
        }
        
        textBgView.addSubview(inspirationBtn)

        inspirationBtn.snp.makeConstraints { make in
            make.height.equalTo(32)
            make.bottom.equalTo(0)
            make.leading.equalTo(0)
        }
        
        textBgView.addSubview(clearBtn)
        clearBtn.snp.makeConstraints { make in
            make.width.height.equalTo(14)
            make.bottom.equalTo(-14)
            make.trailing.equalTo(-14)
        }
        
        textBgView.addSubview(numView)
        numView.snp.makeConstraints { make in
            make.centerY.equalTo(clearBtn)
            make.trailing.equalTo(clearBtn.snp.leading).offset(-8)
        }
    
    }

//    func getVipText()->String{
//        if kPurchaseDefault.isVip {
//            return "Generate"
//        }
//        return "Generate (\(kPurchaseDefault.freeNum(type: .generatePic)))"
//    }
    
}

extension TSPromptTextView: UITextViewDelegate{
    
    func textViewDidBeginEditing(_ textView: UITextView) {
//        self.colComponent?.collectionView.scrollToItem(at: IndexPath(item: 0, section: 0), at: .centeredVertically, animated: true)
    }
    
    func textViewDidChange(_ textView: UITextView) {
        currenMun = textView.text.count
        textChangedBlock?(textView.text)
    }
    
}
